Manim's documentation
=====================

.. image:: https://cdn.jsdelivr.net/gh/3b1b/manim@master/logo/white_with_name.png

Manim is an animation engine for explanatory math videos. It's used to create precise animations programmatically, as seen in the videos
at `3Blue1Brown <https://www.3blue1brown.com/>`_.

And here is a Chinese version of this documentation: https://docs.manim.org.cn/

.. toctree::
   :maxdepth: 2
   :caption: Getting Started

   getting_started/installation
   getting_started/quickstart
   getting_started/configuration
   getting_started/example_scenes
   getting_started/config
   getting_started/structure
   getting_started/whatsnew

.. toctree::
   :maxdepth: 2
   :caption: Documentation

   documentation/constants
   documentation/custom_config

.. toctree::
   :maxdepth: 2
   :caption: Development

   development/changelog
   development/contributing
   development/about
